library(tidyverse)

fichiers <-
  list.files(path = "data",
             pattern = "*.csv",
             full.names = TRUE)

bordee <- 10
premier_mois <- 9

col_spec <- cols(
  .default = col_double(),
  `Nom de la Station` = col_character(),
  `Date/Heure` = col_date()
)

data_neige <- fichiers %>%
  lapply(
    FUN = function(x)
      x %>%
      read_csv(
        # Séparateur décimal
        locale = locale(decimal_mark = ","),
        col_types = col_spec,
        # Valeurs manquantes
        na = c("T", "E", "M", "<31")
      )
  ) %>%
  bind_rows()

premiere_bordee <-
  data_neige %>% 
  # On sélectionne les données d'intérêt
  select(`Date/Heure`, `Année`, Mois, Jour, `Neige tot. (cm)`) %>%
  # On sélectionne les bordées
  filter(`Neige tot. (cm)` >= bordee) %>%
  # On sélectionne à partir de septembre de chaque année
  filter(Mois >= premier_mois) %>%
  # On trie par date
  arrange(`Année`, Mois, Jour) %>%
  # On regroupe par année
  group_by(`Année`) %>%
  # On garde la première date par année
  filter(row_number() == 1) %>%
  # On formate les données pour affichage sur un graphique
  transmute(Date = ISOdate(0, Mois, Jour), neige_cm = `Neige tot. (cm)`)

graph.neige <-
  ggplot2::ggplot(data = premiere_bordee, aes(x = `Année`, y = Date)) +
  geom_point(aes(size = neige_cm)) +
  ggtitle("Date de la première bordée (10 cm) à Montréal")

ggsave("montreal_neige_2019_premiere_bordee.png", plot = graph.neige)
